feat(cccl): integrate missing CCCL directories — python/, ci/, .agent/, docs/, test/
Sparse-checkout from NVIDIA/cccl main branch to complete cccl_upstream: Added: - python/cuda_cccl/ (226 files) — Python bindings for device-level algorithms Critical for muh toolchain: cuda.compute.reduce_into, scan, radix_sort, etc. Includes 204 .py files with full test coverage for all 27 algorithms - ci/ (163 files) — Build/test infrastructure build_cub.sh, test_cub.sh, build_and_test_targets.sh, matrix.yaml Directly maps to our [INFRA-CI] and [INFRA-BUILD] items - .agent/skills/ (7 files) — NVIDIA's own agent skills for CCCL cccl-style/SKILL.md, cccl-test/SKILL.md, sass-diff/SKILL.md - docs/ (491 files) — Official CCCL documentation CI references, CMake guides, Python compute docs, libcudacxx PTX docs - test/ (12 files) — Top-level integration tests (cuda_smoke, stdpar) - Root configs: .clang-format, .clang-tidy, CONTRIBUTING.md, pyproject.toml - CLAUDE.md symlink → AGENTS.md (NVIDIA's standard) cccl_upstream now mirrors full NVIDIA/cccl structure: Before: 42M (cub + thrust + libcudacxx + cudax + c + examples + benchmarks) After: 53M (+python +ci +docs +.agent +test +configs) This completes the CCCL base needed for: - [muh-bench] items: ci/util/build_and_test_targets.sh for targeted builds - [CCCL-verify] items: python/cuda_cccl/tests/ as reference implementations - [CCCL-test] items: ci/test_cub.sh, ci/test_thrust.sh - Agent workflow: .agent/skills/ for consistent style and test patterns
This commit is contained in:
@@ -0,0 +1,80 @@
|
||||
|
||||
shfl.sync
|
||||
^^^^^^^^^
|
||||
|
||||
.. code:: cuda
|
||||
|
||||
// PTX ISA 6.0
|
||||
// shfl.sync.mode.b32 d[|p], a, b, c, membermask;
|
||||
// .mode = { .up, .down, .bfly, .idx };
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_idx(T data,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_idx(T data,
|
||||
bool& pred,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_up(T data,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_up(T data,
|
||||
bool& pred,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_down(T data,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_down(T data,
|
||||
bool& pred,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_bfly(T data,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
template<typename T>
|
||||
[[nodiscard]] __device__ static inline
|
||||
T shfl_sync_bfly(T data,
|
||||
bool& pred,
|
||||
uint32_t lane_idx_offset,
|
||||
uint32_t clamp_segmask,
|
||||
uint32_t lane_mask) noexcept;
|
||||
|
||||
**Constrains and checks**
|
||||
|
||||
The following conditions are checked at *run-time* in debug mode:
|
||||
|
||||
- ``T`` must have 32-bit size (compile-time)
|
||||
- ``lane_idx_offset`` must be less than the warp size
|
||||
- ``clamp_segmask`` must use the bit positions [0:4] and [8:12])
|
||||
- ``lane_mask`` must be a subset of the active mask
|
||||
- All lanes must have the same value for ``lane_mask``
|
||||
- The destination lane must be a member of the ``lane_mask``
|
||||
Reference in New Issue
Block a user